Compute next gradient — BAGO 0.0.1 documentation

# Compute next gradient

A function in the MSData object to find the top signals in the MS1.

computeNextGradient(self, acqFunc='ei')

  Function to calculate the next gradient to run using an acquisition function.

  Parameters:

    acqFunc – str. Acquisition functions in lower case. Valid options are: ei (expected improvement), explore (pure exploration), exploit (pure exploitation), eps (epsilon-greedy algorithm), pi (probability of improvement), rand (random a gradient), ucb (upper confidence bound)

To use this function:

    # You need a gpModel object (model)

    model.computeNextGradient()